@@ -17,13 +17,20 @@
 #' toc_endpoint<-eval(parse(text=paste0("cfg$TOC_ENDPOINT$'",rav,"'$ESTAT$xml")))
 #' \donttest{
 #' options(timeout=2)
-#' xml_leafs<-xml2::xml_find_all(xml2::read_xml(toc_endpoint),".//nt:leaf")
-#' restatapi::extract_toc(xml_leafs[1])
+#' tryCatch(xml_leafs<-xml2::xml_find_all(xml2::read_xml(toc_endpoint),".//nt:leaf"),
+#'          error = function(e) {xml_leafs<-""},
+#'          warning = function(w) {xml_leafs<-""})
+#' if (Sys.info()[['sysname']]=='Windows'){ 
+#'    xml_node<-as.character(xml_leafs[1])
+#' }else{
+#'    xml_node<-xml_leafs[1]
+#' }
+#' if (exists("xml_leafs")) restatapi::extract_toc(xml_node)
 #' options(timeout=60)
 #' }
-#' 
+
 
 extract_toc<-function(ns){
-  # if (Sys.info()[['sysname']]=='Windows'){ns<-xml2::as_xml_document(ns)}
+  if (Sys.info()[['sysname']]=='Windows'){ns<-xml2::as_xml_document(ns)}
   sub("<.*","",sub(".*?>","",as.character(xml2::xml_children(ns)),perl=TRUE))
-}
\ No newline at end of file
+}
